import { Setting } from 'obsidian'
import type LocatorPlugin from 'src/main'
import type { LocatorSettings } from './utils'
import { htmlDescription, isCacheEnabled, needsARestart, saveSettings } from './utils'

export function injectSettingsDanger(
  plugin: LocatorPlugin,
  settings: LocatorSettings,
  containerEl: HTMLElement
) {
  const database = plugin.database

  new Setting(containerEl).setName('Danger Zone').setHeading()

  // Force save cache
  new Setting(containerEl)
    .setName('Force save the cache')
    .setDesc(
      htmlDescription(`Locator has a security feature that automatically disables cache writing if it cannot fully perform the operation.<br>
      Use this option to force the cache to be saved, even if it causes a crash.<br>
      ⚠️ <span style="color: var(--text-accent)">Enabling this setting could lead to crash loops</span>`)
    )
    .addToggle(toggle =>
      toggle.setValue(settings.DANGER_forceSaveCache).onChange(async v => {
        settings.DANGER_forceSaveCache = v
        await saveSettings(plugin)
      })
    )

  // Clear cache data
  if (isCacheEnabled()) {
    new Setting(containerEl)
      .setName('Clear cache data')
      .setDesc(
        htmlDescription(`Erase all Locator cache data.
        Use this if Locator results are inconsistent, missing, or appear outdated.<br>
        ${needsARestart}`)
      )
      .addButton(btn => {
        btn.setButtonText('Clear cache')
        btn.onClick(async () => {
          await database.clearCache()
        })
      })
  }
}
